@@ -39,33 +39,28 @@ extract_to_callback (CajaMenuItem *item,
 		     gpointer          user_data)
 {
 	GList            *files, *scan;
-	CajaFileInfo *file;
 	char             *default_dir;
 	char             *quoted_default_dir;
 	GString          *cmd;
 
 	files = g_object_get_data (G_OBJECT (item), "files");
-	file = files->data;
-
-	default_dir = caja_file_info_get_parent_uri (file);
-
+	default_dir = caja_file_info_get_parent_uri (files->data);
 	quoted_default_dir = g_shell_quote (default_dir);
 
 	cmd = g_string_new ("engrampa");
 	g_string_append_printf(cmd," --default-dir=%s --extract", quoted_default_dir);
 
 	for (scan = files; scan; scan = scan->next) {
-		CajaFileInfo *file = scan->data;
-		char             *uri, *quoted_uri;
+		char *uri, *quoted_uri;
 
-		uri = caja_file_info_get_uri (file);
+		uri = caja_file_info_get_uri (scan->data);
 		quoted_uri = g_shell_quote (uri);
 		g_string_append_printf (cmd, " %s", quoted_uri);
 		g_free (uri);
 		g_free (quoted_uri);
 	}
 
-#ifdef DEBUG
+#ifdef MATE_ENABLE_DEBUG
 	g_print ("EXEC: %s\n", cmd->str);
 #endif
 
@@ -101,7 +96,7 @@ extract_here_callback (CajaMenuItem *item,
 
 	g_spawn_command_line_async (cmd->str, NULL);
 
-#ifdef DEBUG
+#ifdef MATE_ENABLE_DEBUG
 	g_print ("EXEC: %s\n", cmd->str);
 #endif
 
@@ -114,15 +109,12 @@ add_callback (CajaMenuItem *item,
 	      gpointer          user_data)
 {
 	GList            *files, *scan;
-	CajaFileInfo *file;
 	char             *uri, *dir;
 	char             *quoted_uri, *quoted_dir;
 	GString          *cmd;
 
 	files = g_object_get_data (G_OBJECT (item), "files");
-	file = files->data;
-
-	uri = caja_file_info_get_uri (file);
+	uri = caja_file_info_get_uri (files->data);
 	dir = g_path_get_dirname (uri);
 	quoted_dir = g_shell_quote (dir);
 
@@ -134,9 +126,7 @@ add_callback (CajaMenuItem *item,
 	g_free (quoted_dir);
 
 	for (scan = files; scan; scan = scan->next) {
-		CajaFileInfo *file = scan->data;
-
-		uri = caja_file_info_get_uri (file);
+		uri = caja_file_info_get_uri (scan->data);
 		quoted_uri = g_shell_quote (uri);
 		g_string_append_printf (cmd, " %s", quoted_uri);
 		g_free (uri);
@@ -150,14 +140,16 @@ add_callback (CajaMenuItem *item,
 
 
 static struct {
-	char     *mime_type;
-	gboolean  is_compressed;
+	const char *mime_type;
+	gboolean    is_compressed;
 } archive_mime_types[] = {
+		{ "application/vnd.debian.binary-package", TRUE },
+		{ "application/vnd.ms-cab-compressed", TRUE },
 		{ "application/x-7z-compressed", TRUE },
 		{ "application/x-7z-compressed-tar", TRUE },
 		{ "application/x-ace", TRUE },
 		{ "application/x-alz", TRUE },
-		{ "application/x-ar", TRUE },
+		{ "application/x-archive", TRUE },
 		{ "application/x-arj", TRUE },
 		{ "application/x-brotli", TRUE },
 		{ "application/x-brotli-compressed-tar", TRUE },
@@ -165,42 +157,42 @@ static struct {
 		{ "application/x-bzip-compressed-tar", TRUE },
 		{ "application/x-bzip1", TRUE },
 		{ "application/x-bzip1-compressed-tar", TRUE },
-		{ "application/vnd.ms-cab-compressed", TRUE },
 		{ "application/x-cbr", TRUE },
 		{ "application/x-cbz", TRUE },
 		{ "application/x-cd-image", FALSE },
 		{ "application/x-compress", TRUE },
 		{ "application/x-compressed-tar", TRUE },
 		{ "application/x-cpio", TRUE },
-		{ "application/x-deb", TRUE },
 		{ "application/x-ear", TRUE },
-		{ "application/x-ms-dos-executable", FALSE },
 		{ "application/x-gtar", FALSE },
 		{ "application/x-gzip", TRUE },
 		{ "application/x-gzpostscript", TRUE },
 		{ "application/x-java-archive", TRUE },
 		{ "application/x-lha", TRUE },
-		{ "application/x-lhz", TRUE },
+		{ "application/x-lzh-compressed", TRUE },
 		{ "application/x-lzip", TRUE },
 		{ "application/x-lzip-compressed-tar", TRUE },
 		{ "application/x-lzma", TRUE },
 		{ "application/x-lzma-compressed-tar", TRUE },
 		{ "application/x-lzop", TRUE },
 		{ "application/x-lzop-compressed-tar", TRUE },
+		{ "application/x-ms-dos-executable", FALSE },
 		{ "application/x-ms-wim", TRUE },
 		{ "application/x-rar", TRUE },
 		{ "application/x-rar-compressed", TRUE },
 		{ "application/x-rpm", TRUE },
 		{ "application/x-rzip", TRUE },
+		{ "application/x-stuffit", TRUE },
 		{ "application/x-tar", FALSE },
 		{ "application/x-tarz", TRUE },
-		{ "application/x-stuffit", TRUE },
 		{ "application/x-war", TRUE },
 		{ "application/x-xz", TRUE },
 		{ "application/x-xz-compressed-tar", TRUE },
 		{ "application/x-zip", TRUE },
 		{ "application/x-zip-compressed", TRUE },
 		{ "application/x-zoo", TRUE },
+		{ "application/x-zstd", TRUE },
+		{ "application/x-zstd-compressed-tar", TRUE },
 		{ "application/zip", TRUE },
 		{ "multipart/x-zip", TRUE },
 		{ NULL, FALSE }
@@ -435,6 +427,7 @@ caja_fr_register_type (GTypeModule *module)
 		sizeof (CajaFr),
 		0,
 		(GInstanceInitFunc) caja_fr_instance_init,
+		NULL
 	};
 
 	static const GInterfaceInfo menu_provider_iface_info = {
