@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -37,7 +37,6 @@
 #include "typedefs.h"
 
 
-#define ARCHIVE_ICON_SIZE (48)
 #define BAD_CHARS "/\\*"
 #define GET_WIDGET(x) (_gtk_builder_get_widget (data->builder, (x)))
 
@@ -401,16 +400,14 @@ archive_type_combo_box_changed_cb (GtkComboBox *combo_box,
 {
 	const char *mime_type;
 	int         idx = gtk_combo_box_get_active (combo_box);
-	GdkPixbuf  *icon;
+	char       *icon_name;
 
 	mime_type = mime_type_desc[data->supported_types[idx]].mime_type;
-
-	icon = get_mime_type_pixbuf (mime_type, ARCHIVE_ICON_SIZE, NULL);
-	if (icon != NULL) {
-		gtk_image_set_from_pixbuf (GTK_IMAGE (GET_WIDGET ("archive_icon_image")), icon);
-		g_object_unref (icon);
+	if ((icon_name = g_content_type_get_generic_icon_name (mime_type)) != NULL) {
+		gtk_image_set_from_icon_name (GTK_IMAGE (GET_WIDGET ("archive_icon_image")),
+		                              icon_name, GTK_ICON_SIZE_DIALOG);
+		g_free (icon_name);
 	}
-
 	update_sensitivity_for_mime_type (data, mime_type);
 }
 
@@ -510,7 +507,7 @@ dlg_batch_add_files (FrWindow *window,
 	gtk_button_set_label (GTK_BUTTON (GET_WIDGET ("a_add_button")), FR_STOCK_CREATE_ARCHIVE);
 	gtk_expander_set_expanded (GTK_EXPANDER (GET_WIDGET ("a_other_options_expander")), FALSE /*g_settings_get_boolean (data->settings, PREF_BATCH_ADD_OTHER_OPTIONS)*/);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("a_encrypt_header_checkbutton")), g_settings_get_boolean (data->settings_general, PREF_GENERAL_ENCRYPT_HEADER));
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (GET_WIDGET ("a_volume_spinbutton")), (double) g_settings_get_int (data->settings, PREF_BATCH_ADD_VOLUME_SIZE) / MEGABYTE);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (GET_WIDGET ("a_volume_spinbutton")), g_settings_get_int (data->settings, PREF_BATCH_ADD_VOLUME_SIZE) / MEGABYTE);
 
 
 	first_filename = (char*) file_list->data;
