@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -46,24 +46,6 @@ destroy_cb (GtkWidget  *widget,
 }
 
 
-static void
-set_label_type (GtkWidget *label, const char *text, const char *type)
-{
-	char *t;
-
-	t = g_strdup_printf ("<%s>%s</%s>", type, text, type);
-	gtk_label_set_markup (GTK_LABEL (label), t);
-	g_free (t);
-}
-
-
-static void
-set_label (GtkWidget *label, const char *text)
-{
-	set_label_type (label, text, "b");
-}
-
-
 static int
 help_cb (GtkWidget   *w,
 	 DialogData  *data)
@@ -79,8 +61,10 @@ dlg_prop (FrWindow *window)
 	DialogData       *data;
 	GtkWidget        *ok_button;
 	GtkWidget        *help_button;
-	GtkWidget        *label_label;
 	GtkWidget        *label;
+	GFile            *parent;
+	char             *uri;
+	char             *markup;
 	char             *s;
 	goffset           size, uncompressed_size;
 	char             *utf8_name;
@@ -103,22 +87,20 @@ dlg_prop (FrWindow *window)
 
 	/* Set widgets data. */
 
-	label_label = _gtk_builder_get_widget (data->builder, "p_path_label_label");
-	/* Translators: after the colon there is a folder name. */
-	set_label (label_label, _("Location:"));
-
 	label = _gtk_builder_get_widget (data->builder, "p_path_label");
-	s = remove_level_from_path (fr_window_get_archive_uri (window));
-	utf8_name = g_filename_display_name (s);
-	gtk_label_set_text (GTK_LABEL (label), utf8_name);
+	uri = remove_level_from_path (fr_window_get_archive_uri (window));
+	parent = g_file_new_for_uri (uri);
+	utf8_name = g_file_get_parse_name (parent);
+	markup = g_strdup_printf ("<a href=\"%s\">%s</a>", uri, utf8_name);
+	gtk_label_set_markup (GTK_LABEL (label), markup);
+
+	g_free (markup);
 	g_free (utf8_name);
-	g_free (s);
+	g_free (uri);
+	g_object_unref (parent);
 
 	/**/
 
-	label_label = _gtk_builder_get_widget (data->builder, "p_name_label_label");
-	set_label (label_label, C_("File", "Name:"));
-
 	label = _gtk_builder_get_widget (data->builder, "p_name_label");
 	utf8_name = g_uri_display_basename (fr_window_get_archive_uri (window));
 	gtk_label_set_text (GTK_LABEL (label), utf8_name);
@@ -131,33 +113,27 @@ dlg_prop (FrWindow *window)
 
 	/**/
 
-	label_label = _gtk_builder_get_widget (data->builder, "p_date_label_label");
-	set_label (label_label, _("Last modified:"));
-
 	label = _gtk_builder_get_widget (data->builder, "p_date_label");
-	s = get_time_string (get_file_mtime (fr_window_get_archive_uri (window)));
+	GDateTime *date_time;
+	date_time = g_date_time_new_from_unix_local (get_file_mtime (fr_window_get_archive_uri (window)));
+	s = g_date_time_format (date_time, _("%d %B %Y, %H:%M"));
+	g_date_time_unref (date_time);
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
 	/**/
 
-	label_label = _gtk_builder_get_widget (data->builder, "p_size_label_label");
-	set_label (label_label, _("Archive size:"));
-
 	label = _gtk_builder_get_widget (data->builder, "p_size_label");
 	size = get_file_size (fr_window_get_archive_uri (window));
-	s = g_format_size (size);
+	s = g_format_size_full (size, G_FORMAT_SIZE_LONG_FORMAT);
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
 	/**/
 
-	label_label = _gtk_builder_get_widget (data->builder, "p_uncomp_size_label_label");
-	set_label (label_label, _("Content size:"));
-
 	uncompressed_size = 0;
 	if (fr_window_archive_is_present (window)) {
-		int i;
+		guint i;
 
 		for (i = 0; i < window->archive->command->files->len; i++) {
 			FileData *fd = g_ptr_array_index (window->archive->command->files, i);
@@ -166,15 +142,12 @@ dlg_prop (FrWindow *window)
 	}
 
 	label = _gtk_builder_get_widget (data->builder, "p_uncomp_size_label");
-	s = g_format_size (uncompressed_size);
+	s = g_format_size_full (uncompressed_size, G_FORMAT_SIZE_LONG_FORMAT);
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
 	/**/
 
-	label_label = _gtk_builder_get_widget (data->builder, "p_cratio_label_label");
-	set_label (label_label, _("Compression ratio:"));
-
 	label = _gtk_builder_get_widget (data->builder, "p_cratio_label");
 
 	if (uncompressed_size != 0)
@@ -187,14 +160,16 @@ dlg_prop (FrWindow *window)
 
 	/**/
 
-	label_label = _gtk_builder_get_widget (data->builder, "p_files_label_label");
-	set_label (label_label, _("Number of files:"));
-
 	label = _gtk_builder_get_widget (data->builder, "p_files_label");
 	s = g_strdup_printf ("%d", window->archive->command->n_regular_files);
 	gtk_label_set_text (GTK_LABEL (label), s);
 	g_free (s);
 
+	/**/
+
+	label = _gtk_builder_get_widget (data->builder, "p_mime_type_label");
+	gtk_label_set_text (GTK_LABEL (label), window->archive->command->mime_type);
+
 	/* Set the signals handlers. */
 
 	g_signal_connect (G_OBJECT (data->dialog),
