@@ -27,7 +27,7 @@
 typedef struct _EggFileFormatFilterInfo EggFileFormatFilterInfo;
 typedef struct _EggFileFormatSearch EggFileFormatSearch;
 
-enum 
+enum
 {
   MODEL_COLUMN_ID,
   MODEL_COLUMN_NAME,
@@ -38,7 +38,7 @@ enum
   MODEL_COLUMN_DESTROY
 };
 
-enum 
+enum
 {
   SIGNAL_SELECTION_CHANGED,
   SIGNAL_LAST
@@ -76,9 +76,9 @@ struct _EggFileFormatSearch
 
 static guint signals[SIGNAL_LAST] = { 0 };
 
-G_DEFINE_TYPE (EggFileFormatChooser, 
-	       egg_file_format_chooser,
-               GTK_TYPE_EXPANDER);
+G_DEFINE_TYPE_WITH_PRIVATE (EggFileFormatChooser,
+                            egg_file_format_chooser,
+                            GTK_TYPE_EXPANDER);
 static EGG_DEFINE_QUARK (EggFileFormatFilterInfo,
                          egg_file_format_filter_info);
 
@@ -106,8 +106,7 @@ egg_file_format_filter_info_free (gpointer boxed)
       self = boxed;
 
       g_hash_table_unref (self->extension_set);
-      g_slist_foreach (self->extension_list, (GFunc) g_free, NULL);
-      g_slist_free (self->extension_list);
+      g_slist_free_full (self->extension_list, g_free);
       g_free (self->name);
       g_free (self);
     }
@@ -163,9 +162,9 @@ egg_file_format_filter_add_extensions (GtkFileFilter *filter,
 {
   EggFileFormatFilterInfo *info;
   GString *filter_name;
-  const gchar *extptr;
+  gchar **strings;
+  gchar **ptr;
   gchar *pattern;
-  gsize length;
 
   g_assert (NULL != extensions);
 
@@ -183,31 +182,22 @@ egg_file_format_filter_add_extensions (GtkFileFilter *filter,
   else
     filter_name = NULL;
 
-  extptr = extensions;
-  while (*extptr)
+  strings = g_strsplit (extensions, ", ", -1);
+  for (ptr = strings; *ptr; ptr++)
     {
-      length = strcspn (extptr, ",");
-      pattern = g_new (gchar, length + 3);
-
-      memcpy (pattern, "*.", 2);
-      memcpy (pattern + 2, extptr, length);
-      pattern[length + 2] = '\0';
+      pattern = g_strdup_printf ("*%s", *ptr);
 
       if (filter_name)
         {
-          if (extptr != extensions)
+          if (ptr != strings)
             g_string_append (filter_name, ", ");
 
           g_string_append (filter_name, pattern);
         }
 
-      extptr += length;
-
-      if (*extptr)
-        extptr += 2;
-
       g_hash_table_replace (info->extension_set, pattern, pattern);
     }
+  g_strfreev (strings);
 
   if (filter_name)
     {
@@ -229,7 +219,7 @@ selection_changed_cb (GtkTreeSelection     *selection,
   GtkTreeIter parent;
   GtkTreeIter iter;
 
-  if (gtk_tree_selection_get_selected (selection, &model, &iter)) 
+  if (gtk_tree_selection_get_selected (selection, &model, &iter))
     {
       gtk_tree_model_get (model, &iter, MODEL_COLUMN_NAME, &name, -1);
 
@@ -254,7 +244,7 @@ selection_changed_cb (GtkTreeSelection     *selection,
     }
 }
 
-/* XXX This hack is needed, as gtk_expander_set_label seems 
+/* XXX This hack is needed, as gtk_expander_set_label seems
  * not to work from egg_file_format_chooser_init */
 static gboolean
 select_default_file_format (gpointer data)
@@ -386,8 +376,7 @@ egg_file_format_chooser_init (EggFileFormatChooser *self)
   GtkCellRenderer *cell;
   GtkTreeIter iter;
 
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, EGG_TYPE_FILE_FORMAT_CHOOSER, 
-                                            EggFileFormatChooserPrivate);
+  self->priv = egg_file_format_chooser_get_instance_private(self);
 
   self->priv->size_changed_event = 0;
 
@@ -413,7 +402,6 @@ egg_file_format_chooser_init (EggFileFormatChooser *self)
 
   view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (self->priv->model));
   self->priv->selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
 
 /* file format column */
 
@@ -556,7 +544,7 @@ filter_changed_cb (GObject    *object,
   current_filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (object));
   model = GTK_TREE_MODEL (self->priv->model);
 
-  if (gtk_tree_selection_get_selected (self->priv->selection, &model, &iter)) 
+  if (gtk_tree_selection_get_selected (self->priv->selection, &model, &iter))
     {
       while (gtk_tree_model_iter_parent (model, &parent, &iter))
         iter = parent;
@@ -694,7 +682,7 @@ chooser_response_cb (GtkDialog *dialog,
           g_free (filename);
         }
 
-      g_free (basename); 
+      g_free (basename);
     }
 
 }
@@ -727,7 +715,7 @@ egg_file_format_chooser_realize (GtkWidget *widget)
 
   g_object_ref (self->priv->chooser);
 
-  g_signal_connect (self->priv->chooser, "notify::filter", 
+  g_signal_connect (self->priv->chooser, "notify::filter",
                     G_CALLBACK (filter_changed_cb), self);
   gtk_file_chooser_add_filter (self->priv->chooser, self->priv->all_files);
 
@@ -792,8 +780,6 @@ egg_file_format_chooser_class_init (EggFileFormatChooserClass *cls)
   GObjectClass *object_class = G_OBJECT_CLASS (cls);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (cls);
 
-  g_type_class_add_private (cls, sizeof (EggFileFormatChooserPrivate));
-
   object_class->dispose = egg_file_format_chooser_dispose;
   object_class->finalize = egg_file_format_chooser_finalize;
 
@@ -836,7 +822,7 @@ egg_file_format_chooser_add_format_impl (EggFileFormatChooser *self,
   else
     filter = egg_file_format_filter_new (name, TRUE);
 
-  gtk_tree_store_append (self->priv->model, &iter, 
+  gtk_tree_store_append (self->priv->model, &iter,
                          parent > 0 ? &search.iter : NULL);
 
   gtk_tree_store_set (self->priv->model, &iter,
@@ -936,7 +922,7 @@ get_icon_name (const gchar *mime_type)
   return name;
 }
 
-void           
+void
 egg_file_format_chooser_add_pixbuf_formats (EggFileFormatChooser *self,
                                             guint                 parent G_GNUC_UNUSED,
                                             guint               **formats)
@@ -975,7 +961,7 @@ egg_file_format_chooser_add_pixbuf_formats (EggFileFormatChooser *self,
       description = gdk_pixbuf_format_get_description (format);
       name = gdk_pixbuf_format_get_name (format);
 
-      id = egg_file_format_chooser_add_format_impl (self, parent, description, 
+      id = egg_file_format_chooser_add_format_impl (self, parent, description,
                                                     icon, extensions);
 
       g_free (description);
@@ -1034,7 +1020,7 @@ egg_file_format_chooser_remove_format (EggFileFormatChooser *self,
   gtk_tree_store_remove (self->priv->model, &search.iter);
 }
 
-void            
+void
 egg_file_format_chooser_set_format (EggFileFormatChooser *self,
                                     guint                 format)
 {
@@ -1099,7 +1085,7 @@ egg_file_format_chooser_get_format (EggFileFormatChooser *self,
   return format;
 }
 
-void            
+void
 egg_file_format_chooser_set_format_data (EggFileFormatChooser *self,
                                          guint                 format,
                                          gpointer              data,
@@ -1179,14 +1165,14 @@ egg_file_format_chooser_append_extension (EggFileFormatChooser *self,
 
   g_return_val_if_fail (search.success, NULL);
 
-  gtk_tree_model_get (model, &search.iter, 
+  gtk_tree_model_get (model, &search.iter,
                       MODEL_COLUMN_EXTENSIONS, &extensions,
                       -1);
 
-  if (NULL == extensions && 
+  if (NULL == extensions &&
       gtk_tree_model_iter_nth_child (model, &child, &search.iter, 0))
     {
-      gtk_tree_model_get (model, &child, 
+      gtk_tree_model_get (model, &child,
                           MODEL_COLUMN_EXTENSIONS, &extensions,
                           -1);
     }
