@@ -17,9 +17,11 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <config.h>
+
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -76,7 +78,7 @@ get_uncompressed_name_from_archive (FrCommand  *comm,
 			while (g_input_stream_read (stream, buffer, 1, NULL, NULL) > 0) {
 				if (buffer[0] == '\0') {
 					filename = g_strdup (file_name_from_path (str->str));
-#ifdef DEBUG
+#ifdef MATE_ENABLE_DEBUG
 					g_message ("filename is: %s", filename);
 #endif
 					break;
@@ -299,6 +301,14 @@ fr_command_cfile_add (FrCommand     *comm,
 		compressed_filename = g_strconcat (filename, ".rz", NULL);
 	}
 
+	else if (is_mime_type (comm->mime_type, "application/x-zstd")) {
+		fr_process_begin_command (comm->process, "zstd");
+		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, filename);
+		fr_process_end_command (comm->process);
+		compressed_filename = g_strconcat (filename, ".zst", NULL);
+	}
+
 	/* copy compressed file to the dest dir */
 
 	fr_process_begin_command (comm->process, "cp");
@@ -436,6 +446,14 @@ fr_command_cfile_extract (FrCommand  *comm,
 		fr_process_end_command (comm->process);
 	}
 
+	else if (is_mime_type (comm->mime_type, "application/x-zstd")) {
+		fr_process_begin_command (comm->process, "zstd");
+		fr_process_add_arg (comm->process, "-f");
+		fr_process_add_arg (comm->process, "-d");
+		fr_process_add_arg (comm->process, temp_file);
+		fr_process_end_command (comm->process);
+	}
+
 	/* copy uncompress file to the dest dir */
 
 	uncompr_file = remove_extension_from_path (temp_file);
@@ -474,7 +492,7 @@ fr_command_cfile_test (FrCommand   *comm)
 {
 	const char *compress_cmd;
 	if (is_mime_type (comm->mime_type, "application/x-gzip")) {
-	compress_cmd = "gzip";
+		compress_cmd = "gzip";
 	}
 	else if (is_mime_type (comm->mime_type, "application/x-brotli")) {
 		compress_cmd = "brotli";
@@ -496,6 +514,15 @@ fr_command_cfile_test (FrCommand   *comm)
 	}
 	else if (is_mime_type (comm->mime_type, "application/x-lzop")) {
 		compress_cmd = "lzop";
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-zstd")) {
+		compress_cmd = "zstd";
+		fr_process_begin_command (comm->process, compress_cmd);
+		fr_process_add_arg (comm->process, "-v");
+		fr_process_add_arg (comm->process, "--test");
+		fr_process_add_arg (comm->process, comm->filename);
+		fr_process_end_command (comm->process);
+		return;
 	} else { // i.e. if (is_mime_type (comm->mime_type, "application/x-rzip"))
 		g_warning ("Test integrity is unsupported for %s\n", comm->mime_type);
 		return;
@@ -515,6 +542,7 @@ const char *cfile_mime_type[] = { "application/x-gzip",
 				  "application/x-lzop",
 				  "application/x-rzip",
 				  "application/x-xz",
+				  "application/x-zstd",
 				  NULL };
 
 
@@ -571,6 +599,10 @@ fr_command_cfile_get_capabilities (FrCommand  *comm,
 		if (is_program_available ("rzip", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
+	else if (is_mime_type (mime_type, "application/x-zstd")) {
+		if (is_program_available ("zstd", check_command))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
 
 	return capabilities;
 }
@@ -610,6 +642,8 @@ fr_command_cfile_get_packages (FrCommand  *comm,
 		return PACKAGES ("lzop");
 	else if (is_mime_type (mime_type, "application/x-rzip"))
 		return PACKAGES ("rzip");
+	else if (is_mime_type (mime_type, "application/x-zstd"))
+		return PACKAGES ("zstd");
 
 	return NULL;
 }
@@ -665,7 +699,8 @@ fr_command_cfile_get_type ()
 			NULL,
 			sizeof (FrCommandCFile),
 			0,
-			(GInstanceInitFunc) fr_command_cfile_init
+			(GInstanceInitFunc) fr_command_cfile_init,
+			NULL
 		};
 
 		type = g_type_register_static (FR_TYPE_COMMAND,
