@@ -17,9 +17,10 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <config.h>
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
@@ -65,19 +66,26 @@ static void fr_command_class_init  (FrCommandClass *class);
 static void fr_command_init        (FrCommand *afile);
 static void fr_command_finalize    (GObject *object);
 
-char *action_names[] = { "NONE",
-			 "CREATING_NEW_ARCHIVE",
-			 "LOADING_ARCHIVE",
-			 "LISTING_CONTENT",
-			 "DELETING_FILES",
-			 "TESTING_ARCHIVE",
-			 "GETTING_FILE_LIST",
-			 "COPYING_FILES_FROM_REMOTE",
-			 "ADDING_FILES",
-			 "EXTRACTING_FILES",
-			 "COPYING_FILES_TO_REMOTE",
-			 "CREATING_ARCHIVE",
-			 "SAVING_REMOTE_ARCHIVE" };
+const char *action_names[] = { "NONE",
+                               "CREATING_NEW_ARCHIVE",
+                               "LOADING_ARCHIVE",
+                               "LISTING_CONTENT",
+                               "DELETING_FILES",
+                               "TESTING_ARCHIVE",
+                               "GETTING_FILE_LIST",
+                               "COPYING_FILES_FROM_REMOTE",
+                               "ADDING_FILES",
+                               "EXTRACTING_FILES",
+                               "COPYING_FILES_TO_REMOTE",
+                               "CREATING_ARCHIVE",
+                               "SAVING_REMOTE_ARCHIVE" };
+
+#if MATE_ENABLE_DEBUG
+const char * get_action_name (FrAction action)
+{
+	return action_names[action];
+}
+#endif
 
 GType
 fr_command_get_type ()
@@ -94,7 +102,8 @@ fr_command_get_type ()
 			NULL,
 			sizeof (FrCommand),
 			0,
-			(GInstanceInitFunc) fr_command_init
+			(GInstanceInitFunc) fr_command_init,
+			NULL
 		};
 
 		type = g_type_register_static (G_TYPE_OBJECT,
