@@ -58,67 +58,68 @@
 /* The capabilities are computed automatically in
  * compute_supported_archive_types() so it's correct to initialize to 0 here. */
 FrMimeTypeDescription mime_type_desc[] = {
-	{ "application/x-7z-compressed",        ".7z",       N_("7-Zip (.7z)"), 0 },
-	{ "application/x-7z-compressed-tar",    ".tar.7z",   N_("Tar compressed with 7z (.tar.7z)"), 0 },
-	{ "application/x-ace",                  ".ace",      N_("Ace (.ace)"), 0 },
-	{ "application/x-alz",                  ".alz",      NULL, 0 },
-	{ "application/x-ar",                   ".a",        N_("Ar (.a)"), 0 },
-	{ "application/x-ar",                   ".ar",       N_("Ar (.ar)"), 0 },
-	{ "application/x-arj",                  ".arj",      N_("Arj (.arj)"), 0 },
-	{ "application/x-brotli",               ".br",       N_("brotli (.br)"), 0 },
-	{ "application/x-brotli-compressed-tar", ".tar.br", N_("Tar compressed with brotli (.tar.br)"), 0 },
-	{ "application/x-bzip",                 ".bz2",      NULL, 0 },
-	{ "application/x-bzip-compressed-tar",  ".tar.bz2",  N_("Tar compressed with bzip2 (.tar.bz2)"), 0 },
-	{ "application/x-bzip1",                ".bz",       NULL, 0 },
-	{ "application/x-bzip1-compressed-tar", ".tar.bz",   N_("Tar compressed with bzip (.tar.bz)"), 0 },
-	{ "application/vnd.ms-cab-compressed",  ".cab",      N_("Cabinet (.cab)"), 0 },
-	{ "application/vnd.oasis.opendocument.presentation",          ".odp", N_("OpenDocument Presentation"), 0 },
-	{ "application/vnd.oasis.opendocument.spreadsheet",           ".ods", N_("OpenDocument Spreadsheet"), 0 },
-	{ "application/vnd.oasis.opendocument.text",                  ".odt", N_("OpenDocument Text"), 0 },
-	{ "application/vnd.oasis.opendocument.presentation-template", ".otp", N_("OpenDocument Presentation Template"), 0 },
-	{ "application/vnd.oasis.opendocument.spreadsheet-template",  ".ots", N_("OpenDocument Spreadsheet Template"), 0 },
-	{ "application/vnd.oasis.opendocument.text-template",         ".ott", N_("OpenDocument Text Template"), 0 },
-	{ "application/x-cbr",                  ".cbr",      N_("Rar Archived Comic Book (.cbr)"), 0 },
-	{ "application/x-cbz",                  ".cbz",      N_("Zip Archived Comic Book (.cbz)"), 0 },
-	{ "application/x-cd-image",             ".iso",      NULL, 0 },
-	{ "application/x-compress",             ".Z",        NULL, 0 },
-	{ "application/x-compressed-tar",       ".tar.gz",   N_("Tar compressed with gzip (.tar.gz)"), 0 },
-	{ "application/x-cpio",                 ".cpio",     NULL, 0 },
-	{ "application/x-deb",                  ".deb",      NULL, 0 },
-	{ "application/x-ear",                  ".ear",      N_("Ear (.ear)"), 0 },
-	{ "application/x-ms-dos-executable",    ".exe",      N_("Self-extracting zip (.exe)"), 0 },
-	{ "application/x-gzip",                 ".gz",       NULL, 0 },
-	{ "application/x-java-archive",         ".jar",      N_("Jar (.jar)"), 0 },
-	{ "application/x-lha",                  ".lzh",      N_("Lha (.lzh)"), 0 },
-	{ "application/x-lrzip",                ".lrz",      N_("Lrzip (.lrz)"), 0},
-	{ "application/x-lrzip-compressed-tar", ".tar.lrz",  N_("Tar compressed with lrzip (.tar.lrz)"), 0 },
-	{ "application/x-lzip",                 ".lz",       NULL, 0 },
-	{ "application/x-lzip-compressed-tar",  ".tar.lz",   N_("Tar compressed with lzip (.tar.lz)"), 0 },
-	{ "application/x-lzma",                 ".lzma",     NULL, 0 },
-	{ "application/x-lzma-compressed-tar",  ".tar.lzma", N_("Tar compressed with lzma (.tar.lzma)"), 0 },
-	{ "application/x-lzop",                 ".lzo",      NULL, 0 },
-	{ "application/x-lzop-compressed-tar",  ".tar.lzo",  N_("Tar compressed with lzop (.tar.lzo)"), 0 },
-	{ "application/x-ms-wim",               ".wim",      N_("Windows Imaging Format (.wim)"), 0 },
-	{ "application/x-rar",                  ".rar",      N_("Rar (.rar)"), 0 },
-	{ "application/x-rpm",                  ".rpm",      NULL, 0 },
-	{ "application/x-rzip",                 ".rz",       NULL, 0 },
-	{ "application/x-tar",                  ".tar",      N_("Tar uncompressed (.tar)"), 0 },
-	{ "application/x-tarz",                 ".tar.Z",    N_("Tar compressed with compress (.tar.Z)"), 0 },
-	{ "application/x-stuffit",              ".sit",      NULL, 0 },
-	{ "application/x-war",                  ".war",      N_("War (.war)"), 0 },
-	{ "application/x-xz",                   ".xz",       N_("Xz (.xz)"), 0 },
-	{ "application/x-xz-compressed-tar",    ".tar.xz",   N_("Tar compressed with xz (.tar.xz)"), 0 },
-	{ "application/x-zoo",                  ".zoo",      N_("Zoo (.zoo)"), 0 },
-	{ "application/zip",                    ".zip",      N_("Zip (.zip)"), 0 },
+	{ "application/vnd.debian.binary-package",                    ".deb",      N_("Debian package"), 0 },
+	{ "application/vnd.ms-cab-compressed",                        ".cab",      N_("Cabinet"), 0 },
+	{ "application/vnd.oasis.opendocument.presentation",          ".odp",      N_("OpenDocument Presentation"), 0 },
+	{ "application/vnd.oasis.opendocument.spreadsheet",           ".ods",      N_("OpenDocument Spreadsheet"), 0 },
+	{ "application/vnd.oasis.opendocument.text",                  ".odt",      N_("OpenDocument Text"), 0 },
+	{ "application/vnd.oasis.opendocument.presentation-template", ".otp",      N_("OpenDocument Presentation Template"), 0 },
+	{ "application/vnd.oasis.opendocument.spreadsheet-template",  ".ots",      N_("OpenDocument Spreadsheet Template"), 0 },
+	{ "application/vnd.oasis.opendocument.text-template",         ".ott",      N_("OpenDocument Text Template"), 0 },
+	{ "application/x-7z-compressed",                              ".7z",       N_("7-Zip"), 0 },
+	{ "application/x-7z-compressed-tar",                          ".tar.7z",   N_("Tar compressed with 7z"), 0 },
+	{ "application/x-ace",                                        ".ace",      N_("Ace"), 0 },
+	{ "application/x-alz",                                        ".alz",      N_("ALZip archive"), 0 },
+	{ "application/x-archive",                                    ".ar",       N_("Ar"), 0 },
+	{ "application/x-arj",                                        ".arj",      N_("Arj"), 0 },
+	{ "application/x-brotli",                                     ".br",       N_("Brotli compressed file"), 0 },
+	{ "application/x-brotli-compressed-tar",                      ".tar.br",   N_("Tar compressed with brotli"), 0 },
+	{ "application/x-bzip",                                       ".bz2",      N_("Bzip2 compressed file"), 0 },
+	{ "application/x-bzip-compressed-tar",                        ".tar.bz2",  N_("Tar compressed with bzip2"), 0 },
+	{ "application/x-bzip1",                                      ".bz",       N_("Bzip compressed file"), 0 },
+	{ "application/x-bzip1-compressed-tar",                       ".tar.bz",   N_("Tar compressed with bzip"), 0 },
+	{ "application/x-cbr",                                        ".cbr",      N_("Rar Archived Comic Book"), 0 },
+	{ "application/x-cbz",                                        ".cbz",      N_("Zip Archived Comic Book"), 0 },
+	{ "application/x-cd-image",                                   ".iso",      N_("Disc Image File"), 0 },
+	{ "application/x-compress",                                   ".Z",        N_("Unix Compressed Archive file"), 0 },
+	{ "application/x-compressed-tar",                             ".tar.gz",   N_("Tar compressed with gzip"), 0 },
+	{ "application/x-cpio",                                       ".cpio",     N_("Unix CPIO Archive"), 0 },
+	{ "application/x-ear",                                        ".ear",      N_("Ear"), 0 },
+	{ "application/x-gzip",                                       ".gz",       N_("GZip compressed file"), 0 },
+	{ "application/x-java-archive",                               ".jar",      N_("Jar"), 0 },
+	{ "application/x-lzh-compressed",                             ".lzh",      N_("Lha"), 0 },
+	{ "application/x-lrzip",                                      ".lrz",      N_("Lrzip "), 0},
+	{ "application/x-lrzip-compressed-tar",                       ".tar.lrz",  N_("Tar compressed with lrzip"), 0 },
+	{ "application/x-lzip",                                       ".lz",       N_("LZip compressed file"), 0 },
+	{ "application/x-lzip-compressed-tar",                        ".tar.lz",   N_("Tar compressed with lzip"), 0 },
+	{ "application/x-lzma",                                       ".lzma",     N_("LZMA compressed file"), 0 },
+	{ "application/x-lzma-compressed-tar",                        ".tar.lzma", N_("Tar compressed with lzma"), 0 },
+	{ "application/x-lzop",                                       ".lzo",      N_("LZO compressed file"), 0 },
+	{ "application/x-lzop-compressed-tar",                        ".tar.lzo",  N_("Tar compressed with lzop"), 0 },
+	{ "application/x-ms-dos-executable",                          ".exe",      N_("Self-extracting zip"), 0 },
+	{ "application/x-ms-wim",                                     ".wim",      N_("Windows Imaging Format"), 0 },
+	{ "application/x-rar",                                        ".rar",      N_("Rar"), 0 },
+	{ "application/x-rpm",                                        ".rpm",      N_("Red Hat Package Manager file"), 0 },
+	{ "application/x-rzip",                                       ".rz",       N_("RZip compressed file"), 0 },
+	{ "application/x-stuffit",                                    ".sit",      N_("StuffIt Archive"), 0 },
+	{ "application/x-tar",                                        ".tar",      N_("Tar uncompressed"), 0 },
+	{ "application/x-tarz",                                       ".tar.Z",    N_("Tar compressed with compress"), 0 },
+	{ "application/x-war",                                        ".war",      N_("War"), 0 },
+	{ "application/x-xz",                                         ".xz",       N_("Xz compressed file"), 0 },
+	{ "application/x-xz-compressed-tar",                          ".tar.xz",   N_("Tar compressed with xz"), 0 },
+	{ "application/x-zoo",                                        ".zoo",      N_("Zoo"), 0 },
+	{ "application/x-zstd",                                       ".zst",      N_("Zstandard compressed file"), 0 },
+	{ "application/x-zstd-compressed-tar",                        ".tar.zst",  N_("Tar compressed with zstd"), 0 },
+	{ "application/zip",                                          ".zip",      N_("Zip"), 0 },
 	{ NULL, NULL, NULL, 0 }
 };
 
 FrExtensionType file_ext_type[] = {
 	{ ".7z", "application/x-7z-compressed" },
+	{ ".a", "application/x-archive" },
 	{ ".ace", "application/x-ace" },
 	{ ".alz", "application/x-alz" },
-	{ ".a", "application/x-ar" },
-	{ ".ar", "application/x-ar" },
+	{ ".ar", "application/x-archive" },
 	{ ".arj", "application/x-arj" },
 	{ ".bin", "application/x-stuffit" },
 	{ ".br", "application/x-brotli" },
@@ -128,15 +129,15 @@ FrExtensionType file_ext_type[] = {
 	{ ".cbr", "application/x-cbr" },
 	{ ".cbz", "application/x-cbz" },
 	{ ".cpio", "application/x-cpio" },
-	{ ".deb", "application/x-deb" },
+	{ ".deb", "application/vnd.debian.binary-package" },
 	{ ".ear", "application/x-ear" },
 	{ ".exe", "application/x-ms-dos-executable" },
 	{ ".gz", "application/x-gzip" },
 	{ ".iso", "application/x-cd-image" },
 	{ ".jar", "application/x-java-archive" },
-	{ ".lha", "application/x-lha" },
+	{ ".lha", "application/x-lzh-compressed" },
 	{ ".lrz", "application/x-lrzip" },
-	{ ".lzh", "application/x-lha" },
+	{ ".lzh", "application/x-lzh-compressed" },
 	{ ".lz", "application/x-lzip" },
 	{ ".lzma", "application/x-lzma" },
 	{ ".lzo", "application/x-lzop" },
@@ -152,6 +153,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".sit", "application/x-stuffit" },
 	{ ".swm", "application/x-ms-wim" },
 	{ ".tar", "application/x-tar" },
+	{ ".tar.7z", "application/x-7z-compressed-tar" },
 	{ ".tar.br", "application/x-brotli-compressed-tar" },
 	{ ".tar.bz", "application/x-bzip-compressed-tar" },
 	{ ".tar.bz2", "application/x-bzip-compressed-tar" },
@@ -160,17 +162,18 @@ FrExtensionType file_ext_type[] = {
 	{ ".tar.lz", "application/x-lzip-compressed-tar" },
 	{ ".tar.lzma", "application/x-lzma-compressed-tar" },
 	{ ".tar.lzo", "application/x-lzop-compressed-tar" },
-	{ ".tar.7z", "application/x-7z-compressed-tar" },
 	{ ".tar.xz", "application/x-xz-compressed-tar" },
 	{ ".tar.Z", "application/x-tarz" },
+	{ ".tar.zst", "application/x-zstd-compressed-tar" },
 	{ ".taz", "application/x-tarz" },
 	{ ".tbz", "application/x-bzip-compressed-tar" },
 	{ ".tbz2", "application/x-bzip-compressed-tar" },
 	{ ".tgz", "application/x-compressed-tar" },
-	{ ".txz", "application/x-xz-compressed-tar" },
 	{ ".tlz", "application/x-lzip-compressed-tar" },
+	{ ".txz", "application/x-xz-compressed-tar" },
 	{ ".tzma", "application/x-lzma-compressed-tar" },
 	{ ".tzo", "application/x-lzop-compressed-tar" },
+	{ ".udeb", "application/vnd.debian.binary-package" },
 	{ ".war", "application/x-war" },
 	{ ".wim", "application/x-ms-wim" },
 	{ ".xz", "application/x-xz" },
@@ -178,6 +181,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".Z", "application/x-compress" },
 	{ ".zip", "application/zip" },
 	{ ".zoo", "application/x-zoo" },
+	{ ".zst", "application/x-zstd" },
 	{ NULL, NULL }
 };
 
@@ -186,10 +190,10 @@ GList        *CommandList;
 gint          ForceDirectoryCreation;
 GHashTable   *ProgramsCache;
 GPtrArray    *Registered_Commands;
-int           single_file_save_type[64];
-int           save_type[64];
-int           open_type[64];
-int           create_type[64];
+int           single_file_save_type[G_N_ELEMENTS (mime_type_desc)];
+int           save_type[G_N_ELEMENTS (mime_type_desc)];
+int           open_type[G_N_ELEMENTS (mime_type_desc)];
+int           create_type[G_N_ELEMENTS (mime_type_desc)];
 
 
 static void
@@ -285,7 +289,7 @@ static FrCommandCaps
 fr_registered_command_get_capabilities (FrRegisteredCommand *reg_com,
 				        const char          *mime_type)
 {
-	int i;
+	guint i;
 
 	for (i = 0; i < reg_com->caps->len; i++) {
 		FrMimeTypeCap *cap;
@@ -303,7 +307,7 @@ static FrCommandCaps
 fr_registered_command_get_potential_capabilities (FrRegisteredCommand *reg_com,
 						  const char          *mime_type)
 {
-	int i;
+	guint i;
 
 	if (mime_type == NULL)
 		return FR_COMMAND_CAN_DO_NOTHING;
@@ -332,7 +336,7 @@ register_command (GType command_type)
 G_GNUC_UNUSED static gboolean
 unregister_command (GType command_type)
 {
-	int i;
+	guint i;
 
 	for (i = 0; i < Registered_Commands->len; i++) {
 		FrRegisteredCommand *command;
@@ -386,7 +390,7 @@ GType
 get_command_type_from_mime_type (const char    *mime_type,
 				 FrCommandCaps  requested_capabilities)
 {
-	int i;
+	guint i;
 
 	if (mime_type == NULL)
 		return 0;
@@ -411,7 +415,7 @@ GType
 get_preferred_command_for_mime_type (const char    *mime_type,
 				     FrCommandCaps  requested_capabilities)
 {
-	int i;
+	guint i;
 
 	for (i = 0; i < Registered_Commands->len; i++) {
 		FrRegisteredCommand *command;
@@ -432,14 +436,14 @@ get_preferred_command_for_mime_type (const char    *mime_type,
 void
 update_registered_commands_capabilities (void)
 {
-	int i;
+	guint i;
 
 	g_hash_table_remove_all (ProgramsCache);
 
 	for (i = 0; i < Registered_Commands->len; i++) {
 		FrRegisteredCommand *reg_com;
 		FrCommand           *command;
-		int                  j;
+		guint                j;
 
 		reg_com = g_ptr_array_index (Registered_Commands, i);
 		command = (FrCommand*) g_object_new (reg_com->type, NULL);
@@ -497,6 +501,17 @@ get_archive_filename_extension (const char *filename)
 	return NULL;
 }
 
+static gboolean
+is_mime_type_alias (const char *mime_type)
+{
+	size_t i;
+
+	for (i = 0; mime_type_desc[i].mime_type != NULL; i++)
+		if (g_content_type_equals (mime_type_desc[i].mime_type, mime_type))
+			return TRUE;
+
+	return FALSE;
+}
 
 int
 get_mime_type_index (const char *mime_type)
@@ -578,11 +593,11 @@ static void
 compute_supported_archive_types (void)
 {
 	int sf_i = 0, s_i = 0, o_i = 0, c_i = 0;
-	int i;
+	guint i;
 
 	for (i = 0; i < Registered_Commands->len; i++) {
 		FrRegisteredCommand *reg_com;
-		int                  j;
+		guint                j;
 
 		reg_com = g_ptr_array_index (Registered_Commands, i);
 		for (j = 0; j < reg_com->caps->len; j++) {
@@ -592,7 +607,9 @@ compute_supported_archive_types (void)
 			cap = g_ptr_array_index (reg_com->caps, j);
 			idx = get_mime_type_index (cap->mime_type);
 			if (idx < 0) {
-				g_warning ("mime type not recognized: %s", cap->mime_type);
+				if (!is_mime_type_alias (cap->mime_type)) {
+					g_warning ("mime type not recognized: %s", cap->mime_type);
+				}
 				continue;
 			}
 			mime_type_desc[idx].capabilities |= cap->current_capabilities;
