@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <string.h>
@@ -522,7 +522,7 @@ get_dir_list_from_file_list (GHashTable *h_dirs,
 {
 	GList *scan;
 	GList *dir_list = NULL;
-	int    base_dir_len;
+	size_t base_dir_len;
 
 	if (base_dir == NULL)
 		base_dir = "";
@@ -1056,69 +1056,6 @@ g_copy_file_async (GFile                 *source,
 }
 
 
-void
-g_copy_uris_async (GList                 *sources,
-		   GList                 *destinations,
-		   GFileCopyFlags         flags,
-		   int                    io_priority,
-		   GCancellable          *cancellable,
-		   CopyProgressCallback   progress_callback,
-		   gpointer               progress_callback_data,
-		   CopyDoneCallback       callback,
-		   gpointer               user_data)
-{
-	GList *source_files, *destination_files;
-
-	source_files = gio_file_list_new_from_uri_list (sources);
-	destination_files = gio_file_list_new_from_uri_list (destinations);
-
-	g_copy_files_async (source_files,
-			    destination_files,
-			    flags,
-			    io_priority,
-			    cancellable,
-			    progress_callback,
-			    progress_callback_data,
-			    callback,
-			    user_data);
-
-	gio_file_list_free (source_files);
-	gio_file_list_free (destination_files);
-}
-
-
-void
-g_copy_uri_async (const char            *source,
-		  const char            *destination,
-		  GFileCopyFlags         flags,
-		  int                    io_priority,
-		  GCancellable          *cancellable,
-		  CopyProgressCallback   progress_callback,
-		  gpointer               progress_callback_data,
-		  CopyDoneCallback       callback,
-		  gpointer               user_data)
-{
-	GList *source_list;
-	GList *destination_list;
-
-	source_list = g_list_append (NULL, (gpointer)source);
-	destination_list = g_list_append (NULL, (gpointer)destination);
-
-	g_copy_uris_async (source_list,
-			   destination_list,
-			   flags,
-			   io_priority,
-			   cancellable,
-			   progress_callback,
-			   progress_callback_data,
-			   callback,
-			   user_data);
-
-	g_list_free (source_list);
-	g_list_free (destination_list);
-}
-
-
 /* -- g_directory_copy_async -- */
 
 
@@ -1192,8 +1129,7 @@ directory_copy_data_free (DirectoryCopyData *dcd)
 		g_object_unref (dcd->current_destination);
 		dcd->current_destination = NULL;
 	}
-	g_list_foreach (dcd->to_copy, (GFunc) child_data_free, NULL);
-	g_list_free (dcd->to_copy);
+	g_list_free_full (dcd->to_copy, (GDestroyNotify) child_data_free);
 	g_free (dcd);
 }
 
