@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef UI_H
@@ -29,11 +29,11 @@
 
 
 static GtkActionEntry action_entries[] = {
-	{ "FileMenu", NULL, N_("_Archive") },
-	{ "EditMenu", NULL, N_("_Edit") },
-	{ "ViewMenu", NULL, N_("_View") },
-	{ "HelpMenu", NULL, N_("_Help") },
-	{ "ArrangeFilesMenu", NULL, N_("_Arrange Files") },
+	{ "FileMenu",         NULL, N_("_Archive"),       NULL, NULL, NULL },
+	{ "EditMenu",         NULL, N_("_Edit"),          NULL, NULL, NULL },
+	{ "ViewMenu",         NULL, N_("_View"),          NULL, NULL, NULL },
+	{ "HelpMenu",         NULL, N_("_Help"),          NULL, NULL, NULL },
+	{ "ArrangeFilesMenu", NULL, N_("_Arrange Files"), NULL, NULL, NULL },
 
 	{ "About", "help-about",
 	  N_("_About"), NULL,
@@ -193,7 +193,7 @@ static GtkActionEntry action_entries[] = {
 	  G_CALLBACK (activate_action_open_folder_from_sidebar) },
 
 	{ "GoBack", "go-previous",
-	  "Back", NULL,
+	  NULL, NULL,
 	  N_("Go to the previous visited location"),
 	  G_CALLBACK (activate_action_go_back) },
 	{ "GoForward", "go-next",
